@@ -216,7 +216,7 @@ class Postgres_Handler:
         } 
         
     #Method to update a SQL row
-    def update_record(self, **kwargs):
+    def update_record(self, kwargs):
         values_dict = {}
         id_key = 'Id'
         clause_section = ''
@@ -232,7 +232,7 @@ class Postgres_Handler:
         values_dict[self.table_name_key] = table_name
         
         for key, value in kwargs.items():
-            if key.lower() == id_key.lower() or key.lower() == table_name: continue
+            if key.lower() == id_key.lower() or key.lower() == self.table_name_key: continue
             
             clause_section = f' "{key}" = %({key})s AND '
             values_dict[key] = value
@@ -241,15 +241,13 @@ class Postgres_Handler:
 
         if id_key not in kwargs: assert("Error: ID of record required for an update!")
         
-        query_string += f' WHERE "ID"=(id)s'
+        query_string += f' WHERE "ID"=%(Id)s'
         values_dict[id_key] = kwargs[id_key]
         
         sql_query = sql.SQL(query_string).format(sql.Identifier(table_name = kwargs[self.table_name_key]))
-        
         results = self.__run_query(sql_query)
-        return self.__format_results(results)
-    
         
+        return self.__format_results(results)
     
     #Delete command, will use policy or agent number to delete
     #todo - This may requrie removing items from S3 not sure yet how that will work
